@@ -12,6 +12,9 @@ pub mod device;
 pub mod directory;
 pub mod filter;
 pub mod keys;
+#[cfg(feature = "unstable-pre-spec")]
+#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+pub mod knock;
 pub mod media;
 pub mod membership;
 pub mod message;
