@@ -1,5 +1,9 @@
 //! [GET /_matrix/client/r0/sync](https://matrix.org/docs/spec/client_server/r0.6.0#get-matrix-client-r0-sync)
 
+// FIXME: once https://github.com/rust-lang/rust/issues/84332 is resolved
+// the structs can just be non_exhaustive (remove __test_exhaustive)
+#![allow(clippy::exhaustive_structs)]
+
 use std::{collections::BTreeMap, time::Duration};
 
 use js_int::UInt;
@@ -177,6 +181,12 @@ pub struct Rooms {
     #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
     pub invite: BTreeMap<RoomId, InvitedRoom>,
 
+    /// The rooms that the user has knocked on.
+    #[cfg(feature = "unstable-pre-spec")]
+    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
+    pub knock: BTreeMap<RoomId, KnockedRoom>,
+
     #[cfg(not(feature = "unstable-exhaustive-types"))]
     #[doc(hidden)]
     #[serde(skip, default = "crate::private")]
@@ -201,6 +211,8 @@ impl Default for Rooms {
             leave: BTreeMap::new(),
             join: BTreeMap::new(),
             invite: BTreeMap::new(),
+            #[cfg(feature = "unstable-pre-spec")]
+            knock: BTreeMap::new(),
             #[cfg(not(feature = "unstable-exhaustive-types"))]
             __test_exhaustive: crate::private(),
         }
@@ -322,6 +334,26 @@ impl Default for JoinedRoom {
     }
 }
 
+/// Updates to knocked rooms.
+#[derive(Clone, Debug, Default, Deserialize, Serialize)]
+#[cfg(feature = "unstable-pre-spec")]
+#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+#[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
+pub struct KnockedRoom {
+    /// The knock state.
+    pub knock_state: KnockState,
+}
+
+/// A mapping from a key `events` to a list of `StrippedStateEvent`.
+#[derive(Clone, Debug, Default, Deserialize, Serialize)]
+#[cfg(feature = "unstable-pre-spec")]
+#[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+#[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
+pub struct KnockState {
+    /// The list of events.
+    pub events: Vec<AnyStrippedStateEvent>,
+}
+
 /// Unread notifications count.
 #[derive(Clone, Debug, Deserialize, Serialize)]
 pub struct UnreadNotificationsCount {
