@@ -32,7 +32,7 @@ ruma_api! {
 impl Request {
     /// Creates an empty `Request`.
     pub fn new() -> Self {
-        Self
+        Self {}
     }
 }
 
